@@ -3,24 +3,25 @@
 #	BuildScript for Plamo Linux 4.7
 #			by Jun Kuwamura <juk@linet.gr.jp> on 2010-07-27
 # require:
-HTTPD_VER=2.2.14
+HTTPD_VER=2.2.16
 HTTPD=httpd-$HTTPD_VER
 #	postgresql-8.4.x
 #	re2c-0.12.2
 #PHP
-VERSION=5.2.14
+VERSION=5.2.16
 #VERSION=5.2.7RC4
 
 REL=P1
 
 #SUHOSIN
+# http://www.hardened-php.net/suhosin/download.html
 # ex. http://download.suhosin.org/suhosin-0.9.27.tgz
-SUHOSIN=suhosin-0.9.29
+SUHOSIN=suhosin-0.9.32.1
 # ex. http://download.suhosin.org/suhosin-patch-5.2.x-0.9.x.patch.gz
 PAT_VER=
 #PAT_VER=0.9.7
 DOC_ONLY=
-#DOC_ONLY=-1	# -1: php binary package only
+DOC_ONLY=-1	# -1: php binary package only
 #DOC_ONLY=1	# 1: document package only
 
 if [ -f /var/log/packages/php ]; then
@@ -29,9 +30,9 @@ if [ -f /var/log/packages/php ]; then
 fi
 
 PAC_NAME=php-${VERSION}
-SRC_FILE=${PAC_NAME}.tar.gz
+SRC_FILE=${PAC_NAME}.tar.bz2
 SRC_URI="http://jp.php.net/get/$SRC_FILE/from/this/mirror"
-#SRC_URI=http://downloads.php.net/ilia/$SRC_FILE
+SRC_URI=http://downloads.php.net/ilia/$SRC_FILE
 
 if [ "$PAT_VER" != "" ]; then
   PAT_FILE=suhosin-patch-${VERSION}-${PAT_VER}.patch.gz
@@ -112,7 +113,7 @@ if [ -d $PAC_NAME ]; then
 fi
 
 if [ ! -d $PAC_NAME ]; then
- tar xvfz $SRC_DIR/$SRC_FILE
+ tar xvfj $SRC_DIR/$SRC_FILE
  # exit
  cd ${PAC_NAME}
  if [ "x$PAT_VER" != "x" ]; then
@@ -439,9 +440,9 @@ fi
   phpize
   ./configure
   make; make install
-   cat >> ../../ext/extpkg.lis<<__EOFxmlwriter
-$ZTS/xmlwriter.so
-__EOFxmlwriter
+   cat >> ../../ext/extpkg.lis<<__EOFradius
+$ZTS/radius.so
+__EOFradius
    cd ..
 
 # APC3
@@ -452,20 +453,20 @@ __EOFxmlwriter
   ./configure --enable-apc-mmap=yes --with-apxs=/opt/httpd/bin/apxs
   make; make install
   cp -p apc.php $WORK/opt/htdocs/
-  cat >> ../../ext/extpkg.lis<<__EOFapc
+   cd ..
+  cat >> ../ext/extpkg.lis<<__EOFapc
 $ZTS/apc.so
 __EOFapc
-   cd ..
 
 # APD
  pecl install apd
- cat >> ../../ext/extpkg.lis<<__EOFapd
+ cat >> ../ext/extpkg.lis<<__EOFapd
 $ZTS/apd.so
 __EOFapd
 
 # FileInfo
  pecl install fileinfo
- cat >> ../../ext/extpkg.lis<<__EOFfileinfo
+ cat >> ../ext/extpkg.lis<<__EOFfileinfo
 $ZTS/fileinfo.so
 __EOFfileinfo
 
@@ -477,35 +478,35 @@ cd namazu-2.3.1/
  phpize
   ./configure
   make; make install
-  cat >> ../../ext/extpkg.lis<<__EOFnamazu
+   cd ..
+  cat >> ../ext/extpkg.lis<<__EOFnamazu
 $ZTS/namazu.so
 __EOFnamazu
-   cd ..
 
 
 if [ "$SUHOSIN" != "" ]; then
 #curl -o $SUHOSIN.tgz http://www.hardened-php.net/suhosin/_media/$SUHOSIN.tgz\?id=download&cache=cache
-wget http://download.suhosin.org/$SUHOSIN.tgz
+wget -N http://download.suhosin.org/$SUHOSIN.tgz
 tar xvfz $SUHOSIN.tgz
 cd $SUHOSIN/
   phpize 
   ./configure 
   make; make  install
-  cat >> ../../ext/extpkg.lis<<__EOFsuhosin
+  cd ..
+  cat >> ../ext/extpkg.lis<<__EOFsuhosin
 $ZTS/suhosin.so
 __EOFsuhosin
-  cd ..
 fi #SUHOSIN
 
 # UplaodProgress
   pecl install -f uploadprogress
-  cat >> ../../ext/extpkg.lis<<__EOFuploadprogress
+  cat >> ../ext/extpkg.lis<<__EOFuploadprogress
 $ZTS/uploadprogress.so
 __EOFuploadprogress
 
 # BCompiler
   pecl install -f bcompiler
-  cat >> ../../ext/extpkg.lis<<__EOFbcompiler
+  cat >> ../ext/extpkg.lis<<__EOFbcompiler
 $ZTS/bcompiler.so
 __EOFbcompiler
 
